References
==========

This is the technical documentation of icclim. You should find here an overview of the public API as well as the description of internal mechanisms of icclim.

| For beginner, it is recommended to start with :ref:`tutorials`.
| For more abstract discussion about icclim, see :ref:`explanation`.

.. toctree::
    :maxdepth: 2
    :caption: References

    icclim_index_api
    ecad_functions_api
    frequency
    output_metadata
    release_notes
